@@ -24,7 +24,7 @@ use Object::Tiny qw(
 );
 
 use vars '$VERSION';
-$VERSION = '0.52';
+$VERSION = '0.53';
 
 sub go {
     my $class = shift;
@@ -314,7 +314,7 @@ sub copy_etc {
     my $self = shift;
     require File::Copy;
     (my $from = __FILE__) =~ s/[.]pm$//;
-    for my $ext qw(css js) {
+    for my $ext (qw(css js)) {
         my $dest = File::Spec->catfile($self->{doc_root}, "podsite.$ext");
         File::Copy::copy(
             File::Spec->catfile( $from, "podsite.$ext" ),
@@ -327,13 +327,15 @@ sub get_desc {
     my ($self, $what, $file) = @_;
 
     open my $fh, '<', $file or die "Cannot open $file: $!\n";
-    my $desc;
+    my ($desc, $encoding);
     local $_;
     # Cribbed from Module::Build::PodParser.
-    while (<$fh>) {
+    while (not ($desc and $encoding) and $_ = <$fh>) {
         next unless /^=(?!cut)/ .. /^=cut/;  # in POD
-        last if ($desc) = /^  (?:  [a-z:]+  \s+ - \s+  )  (.*\S)  /ix;
+        ($desc) = /^  (?:  [a-z0-9:]+  \s+ - \s+  )  (.*\S)  /ix unless $desc;
+        ($encoding) = /^=encoding\s+(.*\S)/ unless $encoding;
     }
+    Encode::from_to($desc, $encoding, 'UTF-8') if $desc && $encoding;
 
     close $fh or die "Cannot close $file: $!\n";
     print "$what has no POD or no description in a =head1 NAME section\n"
